standardize <- function (object, unchanged=NULL,
                         standardize.y=FALSE, binary.inputs="center"){

  call <- object$call
  if (is.null(call)) call <- object@call
  form <- call$formula
  varnames <- all.vars (form)
  n.vars <- length (varnames)
#
# Decide which variables will be unchanged
#
  transform <- rep ("leave.alone", n.vars)
  if (standardize.y) {
    transform[1] <- "full"
  }
  for (i in 2:n.vars){
    v <- varnames[i]
    if (is.null(call$data)){   # if regression is using the regular workspace
      thedata <- get(v)
    }
    else {                     # if the regression is using a data frame
      thedata <- get(as.character(call$data))[[v]]
    }
    if (is.na(match(v,unchanged))){
      num.categories <- length (unique(thedata[!is.na(thedata)]))
      if (num.categories==2){
        transform[i] <- binary.inputs
      }
      else if (num.categories>2 & is.numeric(thedata)){
        transform[i] <- "full"
      }
    }
  }
#
# New variable names:
#   prefix with "c." if centered or "z." if centered and scaled
#
  varnames.new <- ifelse (transform=="leave.alone", varnames,
    ifelse (transform=="full", paste ("z", varnames, sep="."),
    paste ("c", varnames, sep=".")))
  transformed.variables <- (1:n.vars)[transform!="leave.alone"]

  if (is.null(call$data)){
#
# If the regression is using the regular workspace, define the new variables
#
    for (i in transformed.variables){
      assign (varnames.new[i], rescale(get(varnames[i]), binary.inputs))
    }
  }
  else {
#
# If the regression uses a data frame, define the new variables there
#
    newvars <- NULL
    for (i in transformed.variables){
      assign (varnames.new[i],
        rescale (get (as.character(call$data)) [[varnames[i]]], binary.inputs))
      newvars <- cbind (newvars, get(varnames.new[i]))
    }
    assign (as.character(call$data),
      cbind (get(as.character(call$data)), newvars))
  }
#
# Now call the regression with the new variables
#
  call.new <- call
  L <- sapply (as.list (varnames.new), as.name)
  names(L) <- varnames
  call.new$formula <- do.call (substitute, list (form, L))
  formula <- as.character (call.new$formula)
  if (length(formula)!=3) stop ("formula does not have three components")
  formula <- paste (formula[2],formula[1],formula[3])
  formula <- gsub ("factor(z.", "factor(", formula, fixed=TRUE)
  formula <- gsub ("factor(c.", "factor(", formula, fixed=TRUE)
  formula <- gsub ("| z.", "| ", formula, fixed=TRUE)
  formula <- gsub ("| c.", "| ", formula, fixed=TRUE)
  call.new$formula <- as.formula (formula) 
  return (eval (call.new))
}

rescale <- function (x, binary.inputs){
# function to rescale by subtracting the mean and dividing by 2 sd's
  x.obs <- x[!is.na(x)]
  if (!is.numeric(x)) #x <- as.numeric(factor(x))
    stop ("can't rescale a non-numeric variable")
  if (length(unique(x.obs))==2){
    x <- (x-min(x.obs))/(max(x.obs)-min(x.obs))
    if (binary.inputs=="0/1") return (x)
    else if (binary.inputs=="-0.5,0.5") return (x-0.5)
    else if (binary.inputs=="center") return (x-mean(x.obs))
    else if (binary.inputs=="full") return ((x-mean(x.obs))/(2*sd(x.obs)))
  }      
  else {
    return ((x-mean(x.obs))/(2*sd(x.obs)))
  }
}
